@@ -5,7 +5,7 @@ use Getopt::Long;
 use VMware::vCloud;
 use strict;
 
-my $version = ( split ' ', '$Revision: 1.2 $' )[1];
+my $version = ( split ' ', '$Revision: 1.3 $' )[1];
 
 my ( $username, $password, $hostname);
 my $orgname = 'System';
@@ -20,4 +20,6 @@ my $vcd = new VMware::vCloud ( $hostname, $username, $password, $orgname );
 
 $vcd->config( debug => 1 ); # Turn debug text on.
 
-my $login = $vcd->login; # Login
\ No newline at end of file
+my $login_info = $vcd->login; # Login
+
+print Dumper($login_info);
\ No newline at end of file
